@@ -1,7 +1,7 @@
-from .universe import *
+from .experience import *
 from .datastore import *
 from .exceptions import *
 
 # don't forget to update version here and in setup.py!
-VERSION = "0.4.3"
+VERSION = "1.0.0"
 VERSION_INFO = "final"
\ No newline at end of file
